@@ -33,7 +33,9 @@ describe Yell do
     subject { Yell.load!('yell.yml') }
 
     before do
-      mock(Yell::Configuration).load!('yell.yml') { {} }
+      expect(Yell::Configuration).to(
+        receive(:load!).with('yell.yml') { {} }
+      )
     end
 
     it "should be_kind_of Yell::Logger" do
@@ -45,7 +47,7 @@ describe Yell do
     let(:name) { 'test' }
 
     it "should delegate to the repository" do
-      mock(Yell::Repository)[name]
+      expect(Yell::Repository).to receive(:[]).with(name)
 
       Yell[name]
     end
@@ -55,7 +57,9 @@ describe Yell do
     let(:name) { 'test' }
 
     it "should delegate to the repository" do
-      mock.proxy(Yell::Repository)[name] = logger
+      expect(Yell::Repository).to(
+        receive(:[]=).with(name, logger).and_call_original
+      )
 
       Yell[name] = logger
     end
@@ -70,8 +74,8 @@ describe Yell do
 
     context "fallback to RACK_ENV" do
       before do
-        stub(ENV).key?('YELL_ENV') { false }
-        mock(ENV).key?('RACK_ENV') { true }
+        expect(ENV).to receive(:key?).with('YELL_ENV') { false }
+        expect(ENV).to receive(:key?).with('RACK_ENV') { true }
 
         ENV['RACK_ENV'] = 'rack'
       end
@@ -85,9 +89,9 @@ describe Yell do
 
     context "fallback to RAILS_ENV" do
       before do
-        stub(ENV).key?('YELL_ENV') { false }
-        stub(ENV).key?('RACK_ENV') { false }
-        mock(ENV).key?('RAILS_ENV') { true }
+        expect(ENV).to receive(:key?).with('YELL_ENV') { false }
+        expect(ENV).to receive(:key?).with('RACK_ENV') { false }
+        expect(ENV).to receive(:key?).with('RAILS_ENV') { true }
 
         ENV['RAILS_ENV'] = 'rails'
       end
@@ -101,9 +105,9 @@ describe Yell do
 
     context "fallback to development" do
       before do
-        stub(ENV).key?('YELL_ENV') { false }
-        stub(ENV).key?('RACK_ENV') { false }
-        stub(ENV).key?('RAILS_ENV') { false }
+        expect(ENV).to receive(:key?).with('YELL_ENV') { false }
+        expect(ENV).to receive(:key?).with('RACK_ENV') { false }
+        expect(ENV).to receive(:key?).with('RAILS_ENV') { false }
       end
 
       it "should == 'development'" do
